# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ValidatorSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'Address',
        'name': 'str',
        'host': 'str',
        'port': 'int',
        'url': 'str'
    }

    attribute_map = {
        'address': 'address',
        'name': 'name',
        'host': 'host',
        'port': 'port',
        'url': 'url'
    }

    def __init__(self, address=None, name=None, host=None, port=None, url=None):  # noqa: E501
        """ValidatorSettings - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._name = None
        self._host = None
        self._port = None
        self._url = None
        self.discriminator = None
        if address is not None:
            self.address = address
        if name is not None:
            self.name = name
        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if url is not None:
            self.url = url

    @property
    def address(self):
        """Gets the address of this ValidatorSettings.  # noqa: E501


        :return: The address of this ValidatorSettings.  # noqa: E501
        :rtype: Address
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this ValidatorSettings.


        :param address: The address of this ValidatorSettings.  # noqa: E501
        :type: Address
        """

        self._address = address

    @property
    def name(self):
        """Gets the name of this ValidatorSettings.  # noqa: E501


        :return: The name of this ValidatorSettings.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ValidatorSettings.


        :param name: The name of this ValidatorSettings.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def host(self):
        """Gets the host of this ValidatorSettings.  # noqa: E501


        :return: The host of this ValidatorSettings.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this ValidatorSettings.


        :param host: The host of this ValidatorSettings.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def port(self):
        """Gets the port of this ValidatorSettings.  # noqa: E501


        :return: The port of this ValidatorSettings.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this ValidatorSettings.


        :param port: The port of this ValidatorSettings.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def url(self):
        """Gets the url of this ValidatorSettings.  # noqa: E501


        :return: The url of this ValidatorSettings.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ValidatorSettings.


        :param url: The url of this ValidatorSettings.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValidatorSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValidatorSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
